<!--

Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org

-->

<!-- FILENAME:   info.php                              -->
<!-- AUTOR:      Marcos Martinez Jimenez               -->


<table border="0" width="90%" align="center">
<tr><td class="text6" colspan="4">&nbsp;</td></tr>
<tr><td class="text6" colspan="4"><?php  echo "".$$name_section."\n";?></td></tr>
<tr><td class="text6" colspan="4"><hr color="<?php echo $TLC?>" size="2"></td></tr>
<tr><td class="text6" colspan="4">&nbsp;</td></tr>

<?php

if (isset($_COOKIE["id_session"])) {$id_session=$_COOKIE["id_session"];} else {$id_session="NULL";}
if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="";}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="1";}
if (isset($_GET['task'])) {$task=$_GET['task'];} else {$task="0";}

include ("includes/languages/".$LANGUAGE."/homesite-info.php");
include ("includes/js/ampliar.js");
include ("includes/db_connect.php");
include ("includes/FCKeditor/fckeditor.php");
$info_query=mysql_query("SELECT id_info,headline,topic,body_text,text_type,edited,modified_by,attached_photos
                         FROM info 
                         WHERE section='".$name_section."'", $db);
$info_result=mysql_fetch_array ($info_query);
$album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='".$info_result["id_info"]."'", $db);
$num_photos=mysql_num_rows($album_query);
// Get the current user level to allow access to the restricted sections
$current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
$current_user=mysql_fetch_array ($current_user_query);

if ($task!="editGUI")
   {
   echo "<tr><td class=\"title1\" colspan=\"4\">".$info_result["headline"]."</td><tr>\n".
        "<tr><td class=\"text1-white\" colspan=\"4\">".
        "$HR001".$info_result["edited"]." $HR002 ".$info_result["modified_by"]."</td><tr>".
        "<tr><td colspan=\"4\">&nbsp;</td><tr>\n";
   }

// Show alert message when the info is empty. Otherwise, The attached pic/text is showed.

if (!$info_result)
  {
  echo "<tr><td class=\"alert\"><center>$ALERT001</center></td></tr>";
  } else if ($info_result["attached_photos"]=="NO" && $task!="editGUI")
            {
            echo "<tr><td class=\"text2\" colspan=\"3\">".$info_result["body_text"]."</td></tr>\n";
            } else if ($info_result["attached_photos"]=="YES" && $task!="editGUI")
                      {
                      echo "<tr><td valign=\"top\" class=\"text2\" width=\"70%\"".
                           " colspan=\"3\">".$info_result["body_text"]."</td>".
                           "<td width=\"30%\" align=\"center\">";
                      while ($album_result=mysql_fetch_array($album_query))
                            {
                            echo "<img src=\"photos/infos/".$info_result["id_info"]."".
                                 "/thumbnail-".$album_result["filename"]."\" ".
                                 "onClick=\"ampliar('photos/infos/".$info_result["id_info"]."".
                                 "/".$album_result["filename"]."')\"><br><br>";
                            }
                      echo "</td></tr>\n";
                      }



if ($task!="editGUI")
   {
   echo "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>".
        "<tr><td class=\"text6\" colspan=\"4\"><hr color=\"$BLC\" size=\"$BLS\"></td></tr>";
   }



// If the user was login has a athorized user, then the system shows the edit and delete options
if ($id_session[num]==$num && $id_session[num]!="NULL" && $task!="edit" && $task!="editGUI" && $current_user["level"] == "99")
   {
   echo "<tr><td class=\"link1\" colspan=\"4\" align=\"right\">";
    switch ($EDITOR) {
    case "text-html":
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&task=edit\">$IB001</a>&nbsp;&nbsp;";
       break;
    case "FCKeditor":
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&task=editGUI\">$IB001</a>&nbsp;&nbsp;";
       break;
    case "both":
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&task=edit\">$IB001 (HTML/Text)</a>&nbsp;&nbsp;";
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&task=editGUI\">$IB001 (GUI)</a>&nbsp;&nbsp;";
       break;
    }
  echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num&task=delete\">$IB002</a></td></tr>";
   }

// If the user was loged in and select the edit option (task==edit), then he can modify the whole section.
if ($id_session[num] == $num && $task=="edit" && $id_session[num] != "" && $current_user["level"] == "99")
   {
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"choice\" value=\"$IEBM002\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n".
        "<input type=\"hidden\" name=\"id_info\" value=\"".$info_result["id_info"]."\">";
   $edited=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=4><br><b>$IEM001</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"edited\" value=\"$edited\">".
        "<tr><td class=\"text2b\" colspan=4><br>$IEM002</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\" value=\"".$info_result["headline"]."\"></input>".
        "<tr><td class=\"text2b\" colspan=4><br>$IEM003</td></tr>";
        if ($info_result['text_type']=="text")
           {
           echo "<tr><td colspan=\"4\">".
                "<textarea name=\"body_text\" rows=16 cols=72>".strip_tags($info_result["body_text"]).
                "</textarea></td></tr>"; 
           } else {
                  echo "<tr><td colspan=\"4\">".
                       "<textarea name=\"body_text\" rows=16 cols=72>".$info_result["body_text"].
                       "</textarea></td></tr>";
                  }
        if ($info_result['text_type']=='text'){$select_text="selected=\"selected\"";}
        if ($info_result['text_type']=='html'){$select_html="selected=\"selected\"";}
   echo "<tr><td class=\"text1\"  colspan=4>$TEXT009 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"text\" $select_text>$TEXT010</option>".
        "<option value=\"html\" $select_html>$TEXT011</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$TEXT008<br><br></td></tr>";
   if ($num_photos>=1)
      {
      echo "<tr><td class=\"text1\" colspan=4>$IEM005<br><br></td></tr>".
           "<tr><td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM001</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM002</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM003</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM004</td></tr>";
      }


   mysql_data_seek ($album_query, 0);
   $n=0;
   while ($album_result=mysql_fetch_array($album_query))
         {
         echo "<tr><td align=\"center\" bgcolor=$TNED1>".
              "<INPUT type=\"checkbox\" name=\"id_photo[$n]\" value=\"".$album_result["id_photo"]."\"></td>".
              "<td class=\"text2\" align=\"center\" bgcolor=$TNED2>".$album_result["filename"]."</td>".
              "<td class=\"text2\" align=\"center\" bgcolor=$TNED1>".$album_result["id_photo"]."</td>".
              "<td bgcolor=$TNED2>".
              "<img src=\"photos/infos/".$info_result["id_info"]."/thumbnail-".$album_result["filename"]."\">".
              "</td></tr>";
         $n++;
         }
   $upload_max_filesize=ini_get('upload_max_filesize');
   echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
        "<tr><td class=\"text2b\" colspan=4><br>$IEM006</td></tr>".
        "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$IEM007 $upload_max_filesize<br><br></td></tr>".
        "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
        "&nbsp;<input type=\"submit\" value=\"$IEBM002\"></input><br></td></tr>".
        "</form>";
   }

// If the user was loged in and select the edit option (task==editGUI), then he can modify the whole section using WYSIWYG.
if ($id_session[num] == $num && $task=="editGUI" && $id_session[num] != "" && $current_user["level"] == "99")
   {
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"choice\" value=\"$IEBM002\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n".
        "<input type=\"hidden\" name=\"id_info\" value=\"".$info_result["id_info"]."\">";
   $edited=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=4><br><b>$IEM001</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"edited\" value=\"$edited\">".
        "<tr><td class=\"text2b\" colspan=4><br>$IEM002</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\" value=\"".$info_result["headline"]."\"></input>".
        "<tr><td class=\"text2b\" colspan=4><br>$IEM003</td></tr>";
        echo "<tr><td colspan=\"4\">";
        $oFCKeditor = new FCKeditor('body_text') ;
        $oFCKeditor->BasePath = 'includes/FCKeditor/';
        $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/my_FCKeditor_config.js';
        $oFCKeditor->ToolbarSet = 'HSMtoolbar';
        $oFCKeditor->Height = '350' ;
        $oFCKeditor->Value = $info_result["body_text"];
        $oFCKeditor->Create() ;
        echo "</td></tr>";
        // If the selected option was 'Edit (GUI)' then, se info should be saved as HTML
        echo "<tr><td class=\"text1\" colspan=4>$TEXT009 <SELECT name=\"text_type\" class=\"text1\">".
              "<option value=\"html\" selected=\"selected\">$TEXT011</option>".
              "</SELECT></td></tr>";
   echo "<tr><td class=\"text1\" colspan=4>$TEXT012<br><br></td></tr>";
   if ($num_photos>=1)
      {
      echo "<tr><td class=\"text1\" colspan=4>$IEM005<br><br></td></tr>".
           "<tr><td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM001</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM002</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM003</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM004</td></tr>";
      }


   mysql_data_seek ($album_query, 0);
   $n=0;
   while ($album_result=mysql_fetch_array($album_query))
         {
         echo "<tr><td align=\"center\" bgcolor=$TNED1>".
              "<INPUT type=\"checkbox\" name=\"id_photo[$n]\" value=\"".$album_result["id_photo"]."\"></td>".
              "<td class=\"text2\" align=\"center\" bgcolor=$TNED2>".$album_result["filename"]."</td>".
              "<td class=\"text2\" align=\"center\" bgcolor=$TNED1>".$album_result["id_photo"]."</td>".
              "<td bgcolor=$TNED2>".
              "<img src=\"photos/infos/".$info_result["id_info"]."/thumbnail-".$album_result["filename"]."\">".
              "</td></tr>";
         $n++;
         }
   $upload_max_filesize=ini_get('upload_max_filesize');
   echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
        "<tr><td class=\"text2b\" colspan=4><br>$IEM006</td></tr>".
        "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$IEM007 $upload_max_filesize<br><br></td></tr>".
        "<tr><td class=\"text1\"colspan=4><br>&nbsp;<br></td></tr>".
        "</form>";
   }

if ($id_session[num] == $num && $task=="delete" && $id_session[num] != "" && $current_user["level"] == "99")
   {
   // The section is not really deleted, but is updated with default empty info
   // If you wants to delete it completly, then you need to change the config_site.php file
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        "action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_info\">".
        "<input type=\"hidden\" name=\"choice\" value=\"$IEBM002\">".
        "<input type=\"hidden\" name=\"task\" value=\"delete_files\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n".
        "<input type=\"hidden\" name=\"id_info\" value=\"".$info_result["id_info"]."\">";
   $edited=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=4 align=\"center\"><br><b>$IDM001</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"edited\" value=\"$edited\">".
        "<tr><td class=\"alert3b\" colspan=4\" align=\"center\"><br>$IDM002</td></tr>".
        "<tr><td class=\"text2\" colspan=4\" align=\"center\"><br>$IDM003</td></tr>".
        "<input type=\"hidden\" name=\"headline\" value=\"Headline Tab $top_tab Section $section_type\">".
        "<input type=\"hidden\" name=\"body_text\" value=\"Maybe you want edit this text\">".
        "<tr><td class=\"text1\"colspan=4 align=\"center\"><br><input type=\"submit\" value=\"$IDBM001\"></input><br></td></tr>".
        "</form>";
   }
?>

</table>
